# LLM101
Nybegynnerkurs i enkel bruk av språkmodeller.

## Kom i gang

For å delta i kurset, åpne notebook-en ved å klikke på knappen under:

[![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/bearingpoint-no/LLM101/blob/feature/migrate-to-google-colab/notebooks/LLM101_FINAL_2.ipynb)

💡 **Tips**: Bruk CTRL + klikk (eller CMD + klikk på Mac) for å åpne notebook-en i en ny fane.

**Får du gammel versjon?** 
- Prøv å oppdatere siden (F5 eller CTRL+R)
- Tøm nettleser-cache (CTRL+Shift+R)
- Eller åpne dette alternativet: [Direkte GitHub-link](https://github.com/bearingpoint-no/LLM101/blob/feature/migrate-to-google-colab/notebooks/LLM101_FINAL_2.ipynb) og klikk "Open in Colab" øverst i filen

**Ser du ikke "Open in Colab" på GitHub?**
- Gå til [colab.research.google.com](https://colab.research.google.com)
- Klikk "GitHub" fanen
- Søk etter: `bearingpoint-no/LLM101`
- Velg branch: `feature/migrate-to-google-colab`
- Klikk på `LLM101_FINAL_2.ipynb`

Notebook-en inneholder alt kursmateriale og interaktive øvelser.



---

## Gamle notater

- Et mer relevant dataset, liknende et faktisk usecase
- Ressoneringsmodell for laging av kategorier
- Først gi noen kategorier ("hva bedriften tror") + other, be de kategorisere inn i de
- Deretter be de finne kategoriene selv
- Fortell om data engineering
- SU: Begynn så enkelt som mulig, ikke overkompliser det. Utvid heller om det ikke funger, reiterer, burk feedbacken fra modellen til å gjøre dine prompts tydeligere
- Et poeng som er kult å få inn: Noe nesting av structured outputs
- Spør Arne om dato for mini-modellen